import React, { Component } from 'react';
import * as Diagramming from '@mindfusion/diagramming';
import * as Drawing from '@mindfusion/drawing';
import { DiagramView, Overview, NodeListView, ZoomControl, Ruler } from '@mindfusion/diagramming-react';

class DiagramApp extends Component {
  constructor(props) {
    super(props);

    this.diagramViewControl = React.createRef();

    // create the diagram
    var diagram = new Diagramming.Diagram();

    var theme = new Diagramming.Theme();
    var shapeNodeStyle = new Diagramming.Style();
    shapeNodeStyle.brush = { type: 'SolidBrush', color: '#e0e9e9' };
    shapeNodeStyle.stroke = "#7F7F7F";
    shapeNodeStyle.fontName = "Verdana";
    shapeNodeStyle.fontSize = 4;
    shapeNodeStyle.nodeEffects = [new Diagramming.GlassEffect ()];
    theme.styles.set("std:ShapeNode", shapeNodeStyle);
    diagram.Theme = theme;
    diagram.addEventListener("controlLoaded", (diagram)=> diagram.Bounds(new Drawing.Rect(0, 0, 600, 800)));
    // add some nodes to the NodeListView
    var nodes = [];
    var shapes = ["Actor", "RoundRect", "Triangle", "Decision"];
    for (var i = 0; i < shapes.length; ++i) {
      var node = new Diagramming.ShapeNode(diagram);
      node.Text = shapes[i];
      node.Shape = shapes[i];

      nodes.push(node);
    }

    this.state = {
      diagram: diagram,
      nodes: nodes,
      captions: shapes
    };
  }

  componentDidMount() {
    this.setState({diagramView: this.diagramViewControl.current});
  }

  render() {
    var props = {
      "id": "diagram1",
      "linkHeadShapeSize": 2,
      "routeLinks": true,
      "roundedLinks": true,
      "backBrush": "#e0e9e9"
    };

    return (
      

        <div className="container">
         
            <div className="left-sidebar">
           
              <Overview diagramView={this.state.diagramView}></Overview>
           
              <NodeListView className="item" 
                nodes={this.state.nodes}
                captions={this.state.captions}
              ></NodeListView>
             
            </div>

            <div className="center-area">              
            <Ruler style={{ width: "100%", height:"800px" }}>
                <DiagramView ref={this.diagramViewControl} diagram={this.state.diagram} 
                  {...props}
                  />
            </Ruler>
            </div>
         
          <div className="right-sidebar">
          <ZoomControl diagramView={this.state.diagramView}></ZoomControl>        
        </div>

        </div>      

    );
  }
}


export default DiagramApp;
